//********************************************************************
//*-------------------------------------------------------------------
//* Licensed Materials - Property of IBM
//*
//* 5724-A18
//*
//* (c) Copyright IBM Corp. 2001, 2002
//*
//* US Government Users Restricted Rights - Use, duplication or
//* disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
//*
//*-------------------------------------------------------------------
//*

// set this flag to true if you want to display the debugging XML popup window 
var debug=false;
// set this flag to false if you do not want the contract to be submitted 
// (created/udpated) after the XML popup appears
var submitWhileDebugging=true;

function padZero (entry) {
  if (entry.length == 1)
	return '0' + entry;
  return entry;
}

function ContractGeneralModel()
{
  this.name = "";
  this.title = "";
  this.description = "";
  this.StartImmediateChecked = false;
  this.startYear = "";
  this.startMonth = "";
  this.startDay = "";
  this.startTime = "";
  this.endNeverExpires = false;
  this.endYear = "";
  this.endMonth = "";
  this.endDay = "";
  this.endTime = "";

  this.state = "Draft";
  this.origin = "Manual";
  this.usage = "OrganizationBuyer";
  this.majorVersionNumber = "1";
  this.minorVersionNumber = "0";
  this.referenceNumber = "";
  
  this.creditLineAllowed = false;

  this.accountName = "";
  this.accountOwnerReferenceNumber = "";
  this.accountOwnerReferenceDN = "";
  
  this.remarks = "";
}

function ContractCommonDataModel()
{
  this.storeId = "";
  this.accountHasCredit = true;
  this.accountHolderOrganization = "";
  this.flanguageId = "";
  var storeCurrArray = new Array();
  this.storeCurrArray = storeCurrArray;
  this.storeDefaultCurr = "";
  this.contractHasInclusionExclusionTCs = false;
  this.catalogId = "";
  this.catalogIdentifier = "";
  this.catalogMemberId = "";
  this.catalogMemberDN = "";
  this.storeMemberId = "";
  this.storeMemberDN = "";  
  this.storeIdentity = "";
}

function ContractBuyerModel()
{
  var availableBuyers = new Array();
  this.availableBuyers = availableBuyers;
  var selectedBuyers = new Array();
  this.selectedBuyers = selectedBuyers;
  var contractBuyers = new Array();
  this.contractBuyers = contractBuyers;
}

function ContractDocumentationModel()
{
  var contractDocumentation = new Array();
  this.contractDocumentation = contractDocumentation;
  var deletedDocumentation = new Array();
  this.deletedDocumentation = deletedDocumentation;
  var selectedDocumentation = new Array();
  this.selectedDocumentation = selectedDocumentation;
}

function GMTTimeStamp()
{
    this.year = ""; 
    this.month = "";
    this.date = ""; 
    this.hour = ""; 
    this.minute = "";
    this.second = "00";
}

function checkProductConstraintsData() {

  var lastPageWasPricing = false;
  var lastPage = get("ContractPricingPageVisited", null);
  if (lastPage != null) {
     if (lastPage == "PRICING") {
	lastPageWasPricing = true;
     }
  }
  if (lastPageWasPricing) {
        var ccdm = get("ContractCommonDataModel");
  	if (ccdm.contractHasInclusionExclusionTCs || get("ContractProductConstraintsModel") != null)
  	 {
  	  put("contractVerifyProductConstraints", true);
  	  gotoPanel("notebookProductConstraints");
	  return false;
	 }
  }

  return true;
}

function validateGeneralPanel () {

  //alert('In Validate General');

  var o = get("ContractGeneralModel");

  // NAME
  if (!o.name)
   {
    put("contractNameRequired", true);
    gotoPanel("notebookGeneral");
    return false;
   }
   
  if (!isValidUTF8length(o.name, 200))
   {
    put("contractNameTooLong", true);
    gotoPanel("notebookGeneral");
    return false;
   }

  // TITLE
  if (!o.title)
   {
    put("contractTitleRequired", true);
    gotoPanel("notebookGeneral");
    return false;
   }
   
  if (!isValidUTF8length(o.title, 254))
   {
    put("contractTitleTooLong", true);
    gotoPanel("notebookGeneral");
    return false;
   }   

  // DESCRIPTION
  if (!isValidUTF8length(o.description, 32700))
   {
    put("contractDescriptionTooLong", true);
    gotoPanel("notebookGeneral");
    return false;
   }

  // START DATE
  if (o.StartImmediateChecked == false && !validDate(o.startYear, o.startMonth, o.startDay))
   {
    put("invalidStartDate", true);
    gotoPanel("notebookGeneral");
    return false;
   }

  if (o.StartImmediateChecked == false && !validTime(o.startTime))
   {
    put("invalidStartTime", true);
    gotoPanel("notebookGeneral");
    return false;
   }

  // END DATE
  if (o.endNeverExpires == false && !validDate(o.endYear, o.endMonth, o.endDay))
   {
    put("invalidEndDate", true);
    gotoPanel("notebookGeneral");
    return false;
   }

  if (o.endNeverExpires == false && !validTime(o.endTime))
   {
    put("invalidEndTime", true);
    gotoPanel("notebookGeneral");
    return false;
   }

  // if start and end dates are specified, validate range
  if (o.endNeverExpires == false && ! validateStartEndDateTime(o.startYear, o.startMonth, o.startDay,
                                 o.endYear, o.endMonth, o.endDay,
                                 o.startTime,
                                 o.endTime))
   {
    put("invalidEndAfterStartDate", true);
    gotoPanel("notebookGeneral");
    return false;
   }

  if (debug) {
      preSubmitHandler();
      if (submitWhileDebugging == false) {
          return false;
      }
  }

  return true;
}

function validateBuyerPanel() {
  return true;
}

function validateDocumentationPanel() {
  return true;
}

function validateRemarksPanel() {
  var o = get("ContractRemarksModel");
  var cgm = get("ContractGeneralModel");
  // REMARKS
  if (o != null) {
	  if (!isValidUTF8length(o.remarks, 32700))
	   {
	    put("remarksTooLong", true);
	    gotoPanel("notebookRemarks");
	    return false;
	   }
  }
  else if (cgm != null) {
	  if (!isValidUTF8length(cgm.remarks, 32700))
	   {
	    put("remarksTooLong", true);
	    gotoPanel("notebookRemarks");
	    return false;
	   }
  }

  return true;
}

function submitGeneralPanel(contract, participants) {

  var o = get("ContractGeneralModel");
  var ccdm = get("ContractCommonDataModel");

  contract.creditAllowed = o.creditLineAllowed;
  contract.name = o.name;
  contract.state = o.state;
  contract.majorVersionNumber = o.majorVersionNumber;
  contract.minorVersionNumber = o.minorVersionNumber;
  contract.contractUsage = o.usage;
  contract.origin = o.origin;
  
  contract.ContractOwner = new Object();
  contract.ContractOwner.Member = new Object();
  contract.ContractOwner.Member.Organization = new Object();
  contract.ContractOwner.Member.Organization.distinguishName = ccdm.storeMemberDN;  

  if (o.accountName != "") {
	contract.accountName = o.accountName;
	contract.AccountOwner = new Object();
	contract.AccountOwner.Member = new Object();
	contract.AccountOwner.Member.Organization = new Object();
	contract.AccountOwner.Member.Organization.distinguishName = o.accountOwnerReferenceDN;	
  }

  if (o.referenceNumber != "") {
	// update
	contract.referenceNumber = o.referenceNumber;
  }

  var desc = new Object();
  desc.title = o.title;

  desc.languageId = ccdm.flanguageId;
  if (o.description.length > 0) {
	  desc.longDescription = encodeNewLines(o.description);
  }

  contract.ContractDescription = desc;

  return true;
}

function submitContractDates(contract) {

  var o = get("ContractGeneralModel");

  // Start Date
  if (o.StartImmediateChecked == false) {
  var startDate = new GMTTimeStamp();
  startDate.year =  o.startYear;
  startDate.month = padZero(o.startMonth);
  startDate.date =  padZero(o.startDay);

  var startTime = o.startTime.split(":");
  startDate.hour = padZero(startTime[0]);
  startDate.minute = padZero(startTime[1]);

  contract.StartTime = new Object();
  contract.StartTime.GMTTimeStamp = startDate;
  }

  // End Date
  if (o.endNeverExpires == false) {

    var endDate = new GMTTimeStamp();

    endDate.year = o.endYear;
    endDate.month = padZero(o.endMonth);
    endDate.date = padZero(o.endDay);

    var endTime = o.endTime.split(":");
    endDate.hour = padZero(endTime[0]);
    endDate.minute = padZero(endTime[1]);

    contract.EndTime = new Object();
    contract.EndTime.GMTTimeStamp = endDate;
  }

  return true;
}

function submitBuyerPanel(contract, participants) {
  var o = get("ContractBuyerModel");
  if (o != null) {
	// add the new ones
	// only add new ones that are not currently in the contract
	for (i = 0; i < o.selectedBuyers.length; i++) {
		var name = o.selectedBuyers[i].value;
		if (isNameInArray(name, o.contractBuyers) == false) {
			// this is a new one to add to the contract
			var buyer = new Object();
			buyer.role = "Buyer";
			buyer.action = "new";
			buyer.Member = new Object();
			buyer.Member.Organization = new Object();
			buyer.Member.Organization.distinguishName = name;
			participants[participants.length] = buyer;
		}
	}
	// delete the removed ones
	// only delete ones that are currently in the contract
	for (i = 0; i < o.contractBuyers.length; i++) {
		var name = o.contractBuyers[i];
		if (isNameInTextValueArray(name, o.selectedBuyers) == false) {
			// this is a new one to add to the contract
			var buyer = new Object();
			buyer.role = "Buyer";
			buyer.action = "delete";
			buyer.Member = new Object();
			buyer.Member.Organization = new Object();
			buyer.Member.Organization.distinguishName = name;			
			participants[participants.length] = buyer;
		}
	}
  }
  return true;
}

function submitDocumentationPanel(contract) {

  var o = get("ContractDocumentationModel");
  if (o != null) {
	var documents = new Array();

	// add the new ones
	// only add new ones that are not currently in the contract
	for (i = 0; i < o.selectedDocumentation.length; i++) {
		var name = o.selectedDocumentation[i];
		if (isNameInArray(name, o.contractDocumentation) == false) {
			// this is a new one to add to the contract
			var doc = new Object();
			doc.URL = name;
			doc.action = "new";
			documents[documents.length] = doc;
		}
	}
	// delete the removed ones
	// only delete ones that are currently in the contract
	// and that are not going to be added
	for (i = 0; i < o.deletedDocumentation.length; i++) {
		var name = o.deletedDocumentation[i];
		if (isNameInArray(name, o.contractDocumentation) == true &&
		    isNameInArray(name, o.selectedDocumentation) == false) {
			// this is to delete from the contract
			var doc = new Object();
			doc.URL = name;
			doc.action = "delete";
			documents[documents.length] = doc;
		}
	}

	if (documents.length > 0)
		contract.Attachment = documents;
  }
  return true;
}

function submitRemarksPanel(contract) {

  var o = get("ContractRemarksModel");
  var cgm = get("ContractGeneralModel");
  if (o != null) {
	if (o.remarks.length > 0) {
		contract.comment = encodeNewLines(o.remarks);
	}
  }
  else if (cgm != null)
  {
    contract.comment = cgm.remarks;
  }
  return true;
}

function validateAllPanels()
 {
   if (this.validateGeneralPanel) {
     if (validateGeneralPanel() == false) {
	return false;
     } 
   }
   if (this.validateBuyerPanel) {
     if (validateBuyerPanel() == false) {
	return false;
     } 
   }
   if (this.validateDocumentationPanel) {
     if (validateDocumentationPanel() == false) {
	return false;
     } 
   }
   if (this.validateRemarksPanel) {
     if (validateRemarksPanel() == false) {
	return false;
     } 
   }
//alert("Before Validate Category Pricing");
   if (this.validateCategoryPricing) {
     if (validateCategoryPricing() == false) {
	return false;
     } 
   }
//alert("Before Validate Custom Pricing");
   if (this.validateCustomPricing) {
     if (validateCustomPricing() == false) {
	return false;
     } 
   }
//alert("Before Validate Shipping");
   if (this.validateShipping) {
     if (validateShipping() == false) {
	return false;
     } 
   }
//alert("Before Validate Payment");
   if (this.validatePayment) {
     if (validatePayment() == false) {
	return false;
     } 
   }
//alert("Before Validate Purchase Order");
/* Po is in Account now
   if (this.validatePurchaseOrder) {
     if (validatePurchaseOrder() == false) {
	return false;
     } 
   }
*/
//alert("Before Validate Invoicing");
   if (this.validateInvoicing) {
     if (validateInvoicing() == false) {
	return false;
     } 
   }
//alert("Before Validate Returns");
   if (this.validateReturns) {
     if (validateReturns() == false) {
	return false;
     } 
   }
//alert("Before Validate Order Approval");
   if (this.validateOrderApproval) {
     if (validateOrderApproval() == false) {
	return false;
     } 
   }
//alert("Before Validate Product Constraints");
   if (this.validateProductConstraints) {
     if (validateProductConstraints() == false) {
	return false;
     } 
   }
   // check that the Product Constraints data is valid
   if (checkProductConstraintsData() == false)
	return false;

   if (this.validateContractExtensions) {
     if (validateContractExtensions() == false) {
	return false;
     } 
   }
   
  return true;
 }

function preSubmitHandler()
 {
   addURLParameter("XMLFile", "contract.ContractNotebook");

   var tradingAgreement = new Object();
   var contract = new Object();
   tradingAgreement.Contract = contract;
   Xput("Trading", tradingAgreement);
   putDTDname("B2BTrading.dtd");

   var participants = new Array();

   if (this.submitGeneralPanel) {
     if (submitGeneralPanel(contract, participants) == false) {
	return false;
     } 
   }
   if (this.submitBuyerPanel) {
     if (submitBuyerPanel(contract, participants) == false) {
	return false;
     } 
   }

   if (participants.length > 0)
   	contract.Participant = participants;

   if (this.submitDocumentationPanel) {
     if (submitDocumentationPanel(contract) == false) {
	return false;
     } 
   }

   if (this.submitRemarksPanel) {
     if (submitRemarksPanel(contract) == false) {
	return false;
     } 
   }

   var termsAndConditions = new Array();
//alert("Before Submit Category Pricing");
   if (this.submitCategoryPricing) {
     if (submitCategoryPricing(termsAndConditions) == false) {
	return false;
     } 
   }
//alert("Before Submit Custom Pricing");
   if (this.submitCustomPricing) {
     if (submitCustomPricing(termsAndConditions) == false) {
	return false;
     } 
   }
//alert("Before Submit Shipping");
   if (this.submitShipping) {
     if (submitShipping(termsAndConditions) == false) {
	return false;
     } 
   }
//alert("Before Submit Payment");
   if (this.submitPayment) {
     if (submitPayment(termsAndConditions) == false) {
	return false;
     } 
   }
//alert("Before Submit Purchase Order");
/* PO is in Account now
   if (this.submitPurchaseOrder) {
     if (submitPurchaseOrder(termsAndConditions) == false) {
	return false;
     } 
   }
*/
//alert("Before Submit Invoicing");
   if (this.submitInvoicing) {
     if (submitInvoicing(termsAndConditions) == false) {
	return false;
     } 
   }
//alert("Before Submit Returns");
   if (this.submitReturns) {
     if (submitReturns(termsAndConditions) == false) {
	return false;
     } 
   }
//alert("Before Submit Order Approval");
   if (this.submitOrderApproval) {
     if (submitOrderApproval(termsAndConditions) == false) {
	return false;
     } 
   }
//alert("Before Submit Product Constraints");
   if (this.submitProductConstraints) {
     if (submitProductConstraints(termsAndConditions) == false) {
	return false;
     } 
   }
   if (this.submitContractExtensions) {
     if (submitContractExtensions(termsAndConditions) == false) {
	return false;
     } 
   }

   if (termsAndConditions.length > 0)
	   contract.TermCondition = termsAndConditions;

   if (this.submitContractDates) {
     if (submitContractDates(contract) == false) {
	return false;
     } 
   }
   
   if (debug) {
       popupXMLwindow(tradingAgreement, "Trading")
       //alert(convert2XML(tradingAgreement, "Trading", "B2BTrading.dtd"));	
   }
   
   return true;
 }

function submitErrorHandler(submitErrorMessage, submitErrorStatus)
 {
  if (submitErrorStatus == "DuplicatedContractName")
   {
    put("contractExists", true);
    gotoPanel("notebookGeneral");
   }
  else
   {
    put("contractGenericError", true);
    gotoPanel("notebookGeneral");
   }

 }

function submitFinishHandler(submitFinishMessage)
 {
  if (submitFinishMessage != null && submitFinishMessage != "") {
	var o = get("ContractGeneralModel");
	if (o.referenceNumber == "") {
		// new contract
		alertDialog(submitFinishMessage);
	}
  }
  submitCancelHandler();
 }

function submitCancelHandler()
 {
  if (top.goBack)
   {
    top.goBack();
   }
  else
   {
    window.location.replace("NewDynamicListView?ActionXMLFile=contract.ContractList&cmd=ContractListView");
   }
 }

