//*--------------------------------------------------------------------------------------
//* The sample contained herein is provided to you "AS IS".
//*
//* It is furnished by IBM as a simple example and has not been thoroughly tested
//* under all conditions.  IBM, therefore, cannot guarantee its reliability, 
//* serviceability or functionality.  
//*
//* This sample may include the names of individuals, companies, brands and products 
//* in order to illustrate concepts as completely as possible.  All of these names
//* are fictitious and any similarity to the names and addresses used by actual persons 
//* or business enterprises is entirely coincidental.
//*--------------------------------------------------------------------------------------
//*

function ContractAwardCollectionModel() {
  this.tcReferenceNumber = "";
  this.value = "";
  this.currency = "";
  this.point = "";
}

function ContractAwardRedemptionModel() {
  this.tcReferenceNumber = "";
  this.value = "";
  this.currency = "";
  this.point = "";
}


function validateAwardCollection()
{
  var collectionModel = get("ContractAwardCollectionModel");
  if (collectionModel != null)
  {
  	// Check if point/value/currency is empty 
  	if (!collectionModel.point)
  	{
  		put("pointEmpty", true); 
  		gotoPanel("AwardCollectionTCHeading"); 
  		return false;
  	}
   	if (!collectionModel.value)
   	{
  		put("valueEmpty", true); 
  		gotoPanel("AwardCollectionTCHeading"); 
  		return false;
  	}
  	if (!collectionModel.currency)
  	{
  		put("currencyEmpty", true); 
  		gotoPanel("AwardCollectionTCHeading"); 
  		return false;
  	}
  	// validate whether the value is supported for the currency
 	  var ccdm = get("ContractCommonDataModel");
  	if (isValidCurrency(collectionModel.value, collectionModel.currency, ccdm.flanguageId) == false)
  	{
  		put("contractAwardTCSpecifyCurrencyValue", true); 
  		gotoPanel("AwardCollectionTCHeading"); 
  		return false;
  	}
  }
  return true;
}

function validateAwardRedemption() {
  var redemptionModel = get("ContractAwardRedemptionModel");
  if (redemptionModel != null) {
   	// Check if point/value/currency is empty 
  	if (!redemptionModel.point) {
  		put("pointEmpty", true); 
  		gotoPanel("AwardRedemptionTCHeading"); 
  		return false;
  	}
   	if (!redemptionModel.value) {
  		put("valueEmpty", true); 
  		gotoPanel("AwardRedemptionTCHeading"); 
  		return false;
  	}
  	if (!redemptionModel.currency) {
  		put("currencyEmpty", true); 
  		gotoPanel("AwardRedemptionTCHeading"); 
  		return false;
  	}
  	// validate whether the value is supported for the currency
 	var ccdm = get("ContractCommonDataModel");
  	if (isValidCurrency(redemptionModel.value, redemptionModel.currency, ccdm.flanguageId) == false) {
  		put("contractAwardTCSpecifyCurrencyValue", true); 
  		gotoPanel("AwardRedemptionTCHeading"); 
  		return false;
  	}
   }
  return true;
}


function submitAwardTC(termsAndConditions) {

  var collectionM = get("ContractAwardCollectionModel", null);
  var redemptionM = get("ContractAwardRedemptionModel", null);

  var collectionTC = createXMLAwardCollectionModel(collectionM);
  var redemptionTC = createXMLAwardRedemptionModel(redemptionM);

  // check if there's any TC for Award Collection  
  if (collectionTC != null) {
		termsAndConditions[termsAndConditions.length] = collectionTC;
  }
  
  // check if there's any TC for Award Redemption 
  if (redemptionTC != null) {
		termsAndConditions[termsAndConditions.length] = redemptionTC;
  }

  return true;
}

function createXMLAwardCollectionModel(tcModel) {

  if (tcModel != null) {

	var myCollectionTC = new Object();
	myCollectionTC.AwardTC = new Object();
	myCollectionTC.AwardTC.AwardCollectionTC = new Object();
	myCollectionTC.AwardTC.AwardCollectionTC.point = tcModel.point;
	myCollectionTC.AwardTC.AwardCollectionTC.value = tcModel.value;
	myCollectionTC.AwardTC.AwardCollectionTC.currency = tcModel.currency;

	if (tcModel.tcReferenceNumber != "") {
		// Change the term and condition
		myCollectionTC.action = "update";
		myCollectionTC.referenceNumber = tcModel.tcReferenceNumber;
	} 
	else {
		// Create a new term and condition
		myCollectionTC.action = "new";
	}
	
	//alert(convertToXML(myCollectionTC));
	return myCollectionTC;
	
  }	
   
  return null;
}

function createXMLAwardRedemptionModel(tcModel) {
  
  if (tcModel != null) {

	var myRedemptionTC = new Object();
	myRedemptionTC.AwardTC = new Object();
	myRedemptionTC.AwardTC.AwardRedemptionTC = new Object();
	myRedemptionTC.AwardTC.AwardRedemptionTC.point = tcModel.point;
	myRedemptionTC.AwardTC.AwardRedemptionTC.value = tcModel.value;
	myRedemptionTC.AwardTC.AwardRedemptionTC.currency = tcModel.currency;

	if (tcModel.tcReferenceNumber != "") {
		// Change the term and condition
		myRedemptionTC.action = "update";
		myRedemptionTC.referenceNumber = tcModel.tcReferenceNumber;
	} 
	else {
		// Create a new term and condition
		myRedemptionTC.action = "new";
	}
	
	//alert(convertToXML(myRedemptionTC));
	return myRedemptionTC;
	
  }	
   
  return null;
}

///////////////////////////////////////
// MISC SCRIPTS
///////////////////////////////////////

function loadSelectValue(select, value) {
    for (var i = 0; i < select.length; i++) {
        if (select.options[i].value == value) {
            select.options[i].selected = true;
            return;
        }
    }
} 

///////////////////////////////////////
// SUBMIT/VALIDATION SCRIPTS
///////////////////////////////////////

function validateContractExtensions() {
     if ((validateAwardCollection() == false) || (validateAwardRedemption() == false)) {
	return false;
     } 
   return true;
}


function submitContractExtensions(termsAndConditions) {
   if (this.submitAwardTC) {  
     if (submitAwardTC(termsAndConditions) == false) {
	return false;
     } 
   }
}

