package com.mycompany.award;

//********************************************************************
//*-------------------------------------------------------------------
//* Sample Source
//*
//* 5724-A18
//*
//* (c) Copyright IBM Corp. 2002
//*
//* The source code for this program is not published or otherwise
//* divested of its trade secrets, irrespective of what has been
//* deposited with the US Copyright Office.
//*
//*--------------------------------------------------------------------------------------
//* The sample contained herein is provided to you "AS IS".
//*
//* It is furnished by IBM as a simple example and has not been thoroughly tested
//* under all conditions.  IBM, therefore, cannot guarantee its reliability, 
//* serviceability or functionality.  
//*
//* This sample may include the names of individuals, companies, brands and products 
//* in order to illustrate concepts as completely as possible.  All of these names
//* are fictitious and any similarity to the names and addresses used by actual persons 
//* or business enterprises is entirely coincidental.
//*--------------------------------------------------------------------------------------

import java.sql.*;
import java.util.*;
import java.math.*;
import java.rmi.*;
import javax.ejb.*;
import javax.naming.*;
import java.io.*;

import com.ibm.commerce.contract.commands.*;
import com.ibm.commerce.contract.objects.*;
import com.ibm.commerce.contract.helper.*;
import com.ibm.commerce.contract.util.*;


import com.ibm.commerce.ras.*;
import com.ibm.commerce.server.*;
import com.ibm.commerce.exception.*;
import com.ibm.commerce.command.*;
import com.ibm.commerce.datatype.*;
import com.ibm.commerce.utils.*;


public class AwardValidateContractCmdImpl extends com.ibm.commerce.contract.commands.ValidateContractCmdImpl implements ValidateContractCmd {
	public static final String COPYRIGHT = com.ibm.commerce.copyright.IBMCopyright.SHORT_COPYRIGHT;
	public final static String CLASSNAME = "com.mycompany.award.AwardValidateContractCmdImpl";
	private String istrReturnView = null;
    
/**
 * Validate the occurrence of the Terms and Conditions in the contract.
 * In this default implementation, this method checks:
 *  1. cannot have more than one Award Collection T & C
 *  2. cannot have more than one Award Redemption T & C
 *  3. When setting returns terms and conditions for your contract, you must specify 
 *     both Award Collection T & C and Award Redemption T & C together.
 * all these checks are done in the terms and conditions which do not specified Ts and Cs participant.
 * @exception com.ibm.commerce.exception.ECException.
 * @exception java.rmi.RemoteException.
 * @exception javax.ejb.CreateException.
 * @exception javax.ejb.FinderException.
 * @exception javax.naming.NamingException.
 */
public void validateTCOccurrence() throws ECApplicationException, CreateException, RemoteException, FinderException, NamingException {
	final String methodName = "validateTCOccurrence";
	ECTrace.entry(ECTraceIdentifiers.COMPONENT_CONTRACT, this.getClass().getName(), methodName);

	super.validateTCOccurrence();
	
	ContractAccessBean abContract = new ContractAccessBean();
	abContract.setInitKey_referenceNumber(getContractId().toString());

	TermConditionAccessBean[] collectionList = abContract.getTCsByTCSubTypeWithoutTCParticipant("AwardCollectionTC");
	TermConditionAccessBean[] redemptionList = abContract.getTCsByTCSubTypeWithoutTCParticipant("AwardRedemptionTC");

	// either both AwardCollectionTC and AwardRedemptionTC be specified or neither be specified
	ECTrace.trace(ECTraceIdentifiers.COMPONENT_CONTRACT, this.getClass().getName(), methodName, "check if either both AwardCollectionTC and AwardRedemptionTC be specified or neither be specified in the contract " + getContractId().toString());
	if (((collectionList != null && collectionList.length == 1) && (redemptionList == null || redemptionList.length == 0)) ||
		((collectionList == null || collectionList.length == 0) && (redemptionList != null && redemptionList.length != 0))) {
		
		getResponseProperties().put(
			ECContractCmdConstants.SUBMIT_ERROR_STATUS,
			"AwardCollectionAndredemptionDoNotAppearInPair");
		ECMessage ecm = new ECMessage(ECMessageSeverity.ERROR, ECMessageType.USER, "_ERR_AWARD_COLLECTION_AND_REDEMPTION_DO_NOT_APPEAR_IN_PAIR", "award");
		throw new ECApplicationException(ecm, this.getClass().getName(), methodName, istrReturnView, getResponseProperties());	
		
	}

    // cannot have more than one AwardCollectionTC
    ECTrace.trace(ECTraceIdentifiers.COMPONENT_CONTRACT, this.getClass().getName(), methodName, "check if there are more than one AwardCollectionTC in the contract " + getContractId());
	if (collectionList != null && collectionList.length > 1) {
		
		getResponseProperties().put(
			ECContractCmdConstants.SUBMIT_ERROR_STATUS,
			"CannotHaveMoreThanOneAwardCollectionTC");
		
		ECMessage ecm = new ECMessage(ECMessageSeverity.ERROR, ECMessageType.USER, "_ERR_CANNOT_HAVE_MORE_THAN_ONE_AWARD_COLLECTION_TC", "award");
		throw new ECApplicationException(ecm, this.getClass().getName(), methodName, istrReturnView, getResponseProperties());	
	}
	
    // cannot have more than one AwardRedemptionTC
    ECTrace.trace(ECTraceIdentifiers.COMPONENT_CONTRACT, this.getClass().getName(), methodName, "check if there are more than one AwardRedemptionTC in the contract " + getContractId());
	if (redemptionList != null && redemptionList.length > 1) {
		
		getResponseProperties().put(
			ECContractCmdConstants.SUBMIT_ERROR_STATUS,
			"CannotHaveMoreThanOneAwardRedemptionTC");
		
		ECMessage ecm = new ECMessage(ECMessageSeverity.ERROR, ECMessageType.USER, "_ERR_CANNOT_HAVE_MORE_THAN_ONE_AWARD_REDEMPTION_TC", "award");
		throw new ECApplicationException(ecm, this.getClass().getName(), methodName, istrReturnView, getResponseProperties());		
	}

	
	ECTrace.exit(ECTraceIdentifiers.COMPONENT_CONTRACT, this.getClass().getName(), methodName);
}

/**
 * Set the return view for Tools
 * @param returnView java.lang.String 
 */
public void setReturnViewForTools(String returnView) {
	super.setReturnViewForTools(returnView);
	istrReturnView = returnView;
}
}
