package com.mycompany.award;

//********************************************************************
//*-------------------------------------------------------------------
//* Sample Source
//*
//* 5724-A18
//*
//* (c) Copyright IBM Corp. 2002
//*
//* The source code for this program is not published or otherwise
//* divested of its trade secrets, irrespective of what has been
//* deposited with the US Copyright Office.
//*
//*--------------------------------------------------------------------------------------
//* The sample contained herein is provided to you "AS IS".
//*
//* It is furnished by IBM as a simple example and has not been thoroughly tested
//* under all conditions.  IBM, therefore, cannot guarantee its reliability, 
//* serviceability or functionality.  
//*
//* This sample may include the names of individuals, companies, brands and products 
//* in order to illustrate concepts as completely as possible.  All of these names
//* are fictitious and any similarity to the names and addresses used by actual persons 
//* or business enterprises is entirely coincidental.
//*--------------------------------------------------------------------------------------

import com.ibm.commerce.payment.commands.*;

import java.util.*;

import com.ibm.commerce.ras.*;
import com.ibm.commerce.server.*;
import com.ibm.commerce.command.*;
import com.ibm.commerce.exception.*;

import com.ibm.commerce.order.objects.*;

import com.ibm.commerce.copyright.IBMCopyright;
/**
 * The <code>DoDepositPolicyCmd</code> implementation class for the PayWithAward policy. 
 */
public class DoDepositAwardCmdImpl extends BusinessPolicyCommandImpl implements DoDepositPolicyCmd 
{
	private final static String COPYRIGHT = IBMCopyright.SHORT_COPYRIGHT;
	private final static String CLASSNAME = "com.mycompany.award.DoDepositAwardCmdImpl";

    	private OrderAccessBean iabOrder = null;
    	
	/**
	 * DoDepositAwardCmdImpl constructor comment.
	 */
	public DoDepositAwardCmdImpl() {
		super();
	}
	/**
	 *  Returns the OrderAccessBean representing the Order.  This is the OrderAccessBean passed in to the command.
	 */
	protected OrderAccessBean getOrder () 
	{
		return iabOrder;
	}
	/**
	 * Performs the main business logic of the command.
	 */
	public void performExecute() throws com.ibm.commerce.exception.ECException 
	{
		final String methodName = "performExecute";
		ECTrace.entry( ECTraceIdentifiers.COMPONENT_ORDER, CLASSNAME, methodName );
			
		try 
		{
			String 	strPolicyId = "";
			Long 	nOrderId  	= getOrder().getOrderIdInEJBType();
			
			// Chck that a payment method exists for this order
			OrderPaymentMethodAccessBean abOrdPayMthd = new OrderPaymentMethodAccessBean();
			Enumeration enOrdPayMthd = abOrdPayMthd.findByOrder( nOrderId );
			if ( enOrdPayMthd.hasMoreElements() ) {
				abOrdPayMthd = (OrderPaymentMethodAccessBean) enOrdPayMthd.nextElement();
				strPolicyId  = abOrdPayMthd.getPolicyId();
			}
			else {
				throw new ECSystemException( 
					ECMessage._ERR_PAY_FUNCTION_NOT_SUPPORTED_FOR_PAY_POLICY, CLASSNAME, methodName,
								ECMessageHelper.generateMsgParms( nOrderId.toString(), strPolicyId ) );
			}
	
			
		} catch( javax.ejb.CreateException ex ) {
			throw new ECSystemException( 
					ECMessage._ERR_CREATE_EXCEPTION, CLASSNAME, methodName, ex );
		} catch( javax.ejb.FinderException ex ) {
			throw new ECSystemException( 
					ECMessage._ERR_FINDER_EXCEPTION, CLASSNAME, methodName, ex );
		} catch( javax.naming.NamingException ex ) {
			throw new ECSystemException( 
					ECMessage._ERR_NAMING_EXCEPTION, CLASSNAME, methodName, ex );
		} catch( java.rmi.RemoteException ex ) {
			throw new ECSystemException(
					ECMessage._ERR_REMOTE_EXCEPTION, CLASSNAME, methodName, ex );
		}

		ECTrace.exit( ECTraceIdentifiers.COMPONENT_ORDER, CLASSNAME, methodName );
	}
	/**
	 * Sets the Amount to be deposited.
	 */
	public void setDepositAmount(java.math.BigDecimal depositAmount) {}
	/**
	 * Optional error view name passed in by the Caller.
	 */
	public void setErrorViewName(String sEVN) {}
	/**
	 * The order to be deposited.
	 */
	public void setOrder(OrderAccessBean abOrder) 
	{
		iabOrder = abOrder;
	}
}
