package com.mycompany.award;

//********************************************************************
//*-------------------------------------------------------------------
//* Sample Source
//*
//* 5724-A18
//*
//* (c) Copyright IBM Corp. 2002
//*
//* The source code for this program is not published or otherwise
//* divested of its trade secrets, irrespective of what has been
//* deposited with the US Copyright Office.
//*
//*--------------------------------------------------------------------------------------
//* The sample contained herein is provided to you "AS IS".
//*
//* It is furnished by IBM as a simple example and has not been thoroughly tested
//* under all conditions.  IBM, therefore, cannot guarantee its reliability, 
//* serviceability or functionality.  
//*
//* This sample may include the names of individuals, companies, brands and products 
//* in order to illustrate concepts as completely as possible.  All of these names
//* are fictitious and any similarity to the names and addresses used by actual persons 
//* or business enterprises is entirely coincidental.
//*--------------------------------------------------------------------------------------

import java.rmi.*;
import javax.ejb.*;
import javax.naming.*;

import com.ibm.commerce.payment.commands.*;

import java.math.*;
import java.util.*;
import java.sql.*;

import com.ibm.commerce.ras.*;
import com.ibm.commerce.server.*;
import com.ibm.commerce.command.*;
import com.ibm.commerce.exception.*;

import com.ibm.commerce.copyright.IBMCopyright;
import com.ibm.commerce.datatype.TypedProperty;

import com.ibm.commerce.price.utils.*;
import com.ibm.commerce.account.helper.*;

import com.ibm.commerce.order.objects.*;
import com.ibm.commerce.common.objects.*;
import com.ibm.commerce.contract.objects.*;
import com.ibm.commerce.ordermanagement.objects.*;
import com.ibm.commerce.payment.objects.*;

/**
 * The <code>DoRefundPolicyCmd</code> implementation class for the PayWithAward policy.
 * This sample command creates a row in the OrdPayMthd Table to represent the Refund due to the customer.
 */
public class DoRefundAwardCmdImpl extends BusinessPolicyCommandImpl implements DoRefundPolicyCmd 
{
	private final static String COPYRIGHT = IBMCopyright.SHORT_COPYRIGHT;
	private final static String CLASSNAME = "com.mycompany.award.DoRefundAwardCmdImpl";

	private String          sPayMethod         = null;
	private OrderAccessBean iabOrder           = null;
	private RMAAccessBean   iabRMA             = null;
	private BigDecimal      inRefundAmount     = null;
	private String          isErrorViewName    = ERRTASK_NAME;

	private BigDecimal      inChargeAmount          = null;
	private String          isChargeAmountCurrency  = null;				//d30304
	
	private Long              inAccountId           = null;
	private AccountAccessBean iabAccount            = null;

	/**
	 * DoRefundAwardCmdImpl default constructor.
	 */
	public DoRefundAwardCmdImpl() {
		super();
	}
	/**
	 * Checks the currency of the Order and the Store default currency. Converts the refund amount to 
	 * the Store default currency and stores in ChargeAmount if the two currencies are different.
	 * Otherwise, stores the refund amount as-is in the ChargeAmount.
	 */
	protected void checkCurrencyAndGetChargeAmount() 
			throws javax.ejb.CreateException, javax.ejb.FinderException,
					javax.naming.NamingException, java.rmi.RemoteException, ECException 
	{
		final String methodName = "checkCurrencyAndGetChargeAmount";
		ECTrace.entry( ECTraceIdentifiers.COMPONENT_ORDER, CLASSNAME, methodName );
		
		String sOrderCurrency = getOrder().getCurrency();
		//String sRMACurrency = getRMA().getCurrency();													//B@d30304

		CurrencyManager currMgr = CurrencyManager.getInstance();
		StoreAccessBean abStore = getCommandContext().getStore( getOrder().getStoreEntityIdInEJBType() );
		String sStoreDefaultCurrency = currMgr.getDefaultCurrency( abStore, abStore.getLanguageIdInEJBType() );

		if ( sOrderCurrency.equals(sStoreDefaultCurrency) ) {											//E@d30304
			setChargeAmount(getRefundAmount());
		} else {
			MonetaryAmount amount = new MonetaryAmount(getRefundAmount(), sOrderCurrency);
			amount = currMgr.convert( amount, getCommandContext().getStore(), sStoreDefaultCurrency );	//d30304

			if (amount == null) {
				// currency convertion failed
				TypedProperty nvps = new TypedProperty();
				nvps.put( ECConstants.EC_ERROR_CODE, PaymentConstants.ERR_CODE_CURRENCY_CONVERT_FAIL );
				nvps.put( ECConstants.EC_ORDER_RN  , getOrder().getOrderId() );
				throw new ECApplicationException(
						ECMessage._ERR_PAY_CURRENCY_CONVERT_FAIL, CLASSNAME, methodName,
						ECMessageHelper.generateMsgParms( getOrder().getOrderId() ),
						ERRTASK_NAME, nvps );
			}
			
			setChargeAmount(amount.getValue());
		}
		setChargeAmountCurrency( sStoreDefaultCurrency );												//d30304
		
		ECTrace.exit( ECTraceIdentifiers.COMPONENT_ORDER, CLASSNAME, methodName );
	}
	/**
	 * This method will first check if the local variable is set or not.
	 * If not set, the method will attempt to create a new AccessBean 
	 * that represents the Account object.
	 */
	protected AccountAccessBean getAccount () {
		if (iabAccount == null && inAccountId != null) {
			iabAccount = new AccountAccessBean();
			iabAccount.setInitKey_accountId( getAccountId().toString() );
		}
				
		return iabAccount;
	}
	/**
	 *  Retrieve Account Reference Number
	 */
	protected Long getAccountId () { return inAccountId; }
	/**
	 *  Returned Charge Amount
	 */
	protected BigDecimal getChargeAmount () { return inChargeAmount; }
	/**
	 * Returns the currency of the Charge Amount.
	 *
	 * @return The currency of the Charge Amount.
	 *
	 * @see getChargeAmount
	 */
	protected String getChargeAmountCurrency() {
		return isChargeAmountCurrency;
	}
	/**
	 * Retrieve the error view name passed in by the Caller.
	 */
	protected String getErrorViewName () { return isErrorViewName; }
	/**
	 *  Returns the OrderAccessBean representing the Order.  This is the OrderAccessBean passed in to the command.
	 */
	protected OrderAccessBean getOrder () {
		return iabOrder;
	}
	protected BigDecimal getRefundAmount () {
		return inRefundAmount;
	}
	/**
	 * Retrieve RMA
	 */
	protected RMAAccessBean getRMA () { return iabRMA; }
	/**
	 * Performs the main business logic of the command.
	 * @exception ECException
	 */
	public void performExecute() throws com.ibm.commerce.exception.ECException 
	{
		final String methodName = "performExecute";
	
		ECTrace.entry( ECTraceIdentifiers.COMPONENT_ORDER, CLASSNAME, methodName );
			
		try 
		{
			// Check Currency and create a row in the OrdPayMthd table to represent the refund.
			//
			checkCurrencyAndGetChargeAmount();
			retrieveActiveAccountIdFromOrder();
			refundAwardPoint();
			updateOrderPaymentMethod();				
			
		} catch( javax.ejb.CreateException ex ) {
			throw new ECSystemException( ECMessage._ERR_CREATE_EXCEPTION, CLASSNAME, methodName, ex );
		} catch( javax.ejb.FinderException ex ) {
			throw new ECSystemException( ECMessage._ERR_FINDER_EXCEPTION, CLASSNAME, methodName, ex );
		} catch( javax.naming.NamingException ex ) {
			throw new ECSystemException( ECMessage._ERR_NAMING_EXCEPTION, CLASSNAME, methodName, ex );
		} catch( java.rmi.RemoteException ex ) {
			throw new ECSystemException( ECMessage._ERR_REMOTE_EXCEPTION, CLASSNAME, methodName, ex );
		}
		
		
		ECTrace.exit( ECTraceIdentifiers.COMPONENT_ORDER, CLASSNAME, methodName );
	}
	protected void refundAwardPoint() throws FinderException, CreateException, NamingException, RemoteException, ECApplicationException
	{
		final String methodName = "refundAwardPoint";
		ECTrace.entry( ECTraceIdentifiers.COMPONENT_ORDER, CLASSNAME, methodName );
		
		OrderAccessBean abOrder = getOrder();
	
		OrderItemAccessBean[] orderItems = abOrder.getOrderItems();
		String tradingId = orderItems[0].getContractId();
	
		// Make sure all order items are purchased under the same contract (required by this example)
		for (int i=1; i < orderItems.length; i++ ) {
			if (!tradingId.equalsIgnoreCase(orderItems[i].getContractId()) ) {
				ECMessage ecm = new ECMessage(ECMessageSeverity.ERROR, ECMessageType.USER, "_ERR_ORDERITEMS_FROM_MULTIPLE_CONTRACTS", "award");
				throw new ECApplicationException(ecm, this.getClass().getName(), methodName);	
			}
		}

		// Look-up the Terms & Conditions object
		TradingAgreementAccessBean abTA = new TradingAgreementAccessBean();
		abTA.setInitKey_tradingId(tradingId);
		TermConditionAccessBean[] tcs = abTA.getTCsByTCSubType("AwardRedemptionTC", getUserId());
	
		if ( (tcs != null) && (tcs.length !=0) ) {
			
			// get the AwardRedemptionTC
			AwardRedemptionTCAccessBean abAwardRedemptionTC = new AwardRedemptionTCAccessBean();
			abAwardRedemptionTC.setInitKey_referenceNumber(tcs[0].getReferenceNumber());
	
			String cur = abAwardRedemptionTC.getCurrency();
			
			if ( cur.equalsIgnoreCase(getChargeAmountCurrency()) ) {
				// Get the ratio of how many points are awarded per amount spent
				BigDecimal amount = abAwardRedemptionTC.getValueInEJBType();
				Integer points = abAwardRedemptionTC.getPointInEJBType();
				
				int pointCharged = BigDecimal.valueOf(points.longValue(), 0).multiply(getChargeAmount()).divide(amount, 0, BigDecimal.ROUND_CEILING).intValue();

				AwardAccessBean abAward = new AwardAccessBean();
				abAward.setInitKey_memberId(getUserId().toString());
				abAward.setInitKey_tradingId(tradingId);

				int currentPoint = abAward.getPointInEJBType().intValue();
				int newPoint = currentPoint + pointCharged;

				abAward.setPoint(new Integer(newPoint));
				abAward.commitCopyHelper();
			}
			else {
				ECMessage ecm = new ECMessage(ECMessageSeverity.ERROR, ECMessageType.USER, "_ERR_REFUND_CURRENCY_NOT_MATCH_WITH_AWARD_REDEMPTION_TC ", "award");
				throw new ECApplicationException(ecm, this.getClass().getName(), methodName);	
			}
		} else {
			ECMessage ecm = new ECMessage(ECMessageSeverity.ERROR, ECMessageType.USER, "_ERR_NO_AWARD_REDEMPTION_TC", "award");
			throw new ECApplicationException(ecm, this.getClass().getName(), methodName);	
		}
		ECTrace.exit( ECTraceIdentifiers.COMPONENT_ORDER, CLASSNAME, methodName );
	}
	public void reset() 
	{
		// Reset instance variables
	
		iabOrder = null;
		iabRMA   = null;
		inRefundAmount = null;
		isErrorViewName       = ERRTASK_NAME;
		inAccountId       = null;
		iabAccount        = null;
		inChargeAmount    = null;
	}
	/**
	 *  This is called by performExecute to retrieve Account Id from RMA
	 */
	protected void retrieveActiveAccountIdFromOrder()
			throws javax.ejb.CreateException,javax.ejb.FinderException,
					javax.naming.NamingException,java.rmi.RemoteException,
					ECException {

		final String methodName = "retrieveActiveAccountIdFromOrder";
		ECTrace.entry( ECTraceIdentifiers.COMPONENT_ORDER, CLASSNAME, methodName );


		// get the trading Id from RMA
		String sTradingId = getRMA().getTradingId();

		// Make sure the Id is not null.
		if (sTradingId != null) {
			TradingAgreementAccessBean abTA = new TradingAgreementAccessBean();
			abTA.setInitKey_tradingId(sTradingId);
			Long nCurrAccountId = abTA.getAccountIdInEJBType();

			if (nCurrAccountId != null) {
		
				setAccountId(nCurrAccountId);

				//  This check is optional..  can be removed if not needed.
				//  Activeness of the  Account should have been check before this Task Cmd is called
				if (!getAccount().getState().equals(ECAccountConstants.EC_STATE_ACTIVE.toString())) {
					TypedProperty nvps = new TypedProperty();
					nvps.put( ECConstants.EC_ERROR_CODE, PaymentConstants.ERR_CODE_ACCOUNT_NOT_AVAILABLE );
					nvps.put( ECConstants.EC_ORDER_RN  , getAccountId() );
					throw new ECApplicationException(
							ECMessage._ERR_PAY_ACCOUNT_NOT_AVAILABLE, CLASSNAME, methodName,
							ECMessageHelper.generateMsgParms( getAccountId() ),
							ERRTASK_NAME, nvps );
				}
			}
		}
		
		ECTrace.exit( ECTraceIdentifiers.COMPONENT_ORDER, CLASSNAME, methodName );
	}
	/**
	 * Sets the accountId property of the command.
	 *
	 * @param nAccountId the Account ID.
	 */
	protected void setAccountId (Long nAccountId) { inAccountId = nAccountId; }
	/**
	 * Sets the nChargeAmount property of the command.
	 *
	 * @param nChargeAmount the Charge Amount of this refund.
	 */
	protected void setChargeAmount (BigDecimal nChargeAmount) { inChargeAmount = nChargeAmount; }
	/**
	 * Sets the chargeAmountCurrency property of the command.
	 *
	 * @param sCurrency the Charge Amount Currency.
	 */
	protected void setChargeAmountCurrency (String sCurrency) 
	{ 
		isChargeAmountCurrency = sCurrency; 
	}
	/**
	 * Optional error view name passed in by the Caller.
	 */
	public void setErrorViewName (String sEVN) { isErrorViewName = sEVN;}
	/**
	 * Sets the order property of the command.
	 *
	 * @param abOrder the OrderAccessBean representing the Order associated with 
	 * the Return Merchandise Authorization.
	 */
	public void setOrder (OrderAccessBean ab) {
		iabOrder = ab;
	}
	/**
	 * Sets the refundAmount property of the command.
	 *
	 * @param refundAmount the amount to be refunded.
	 */
	public void setRefundAmount(BigDecimal refundAmount) {inRefundAmount = refundAmount;}
	/**
	 * Sets the RMA AccessBean representing the Return Merchandise Authorization record.
	 */
	public void setRMA (RMAAccessBean ab) { iabRMA=ab; }
	/**
	 *  This method is called by performExecute to update ORDPAYMTHD table with refund info
	 */
	protected void updateOrderPaymentMethod () 
			throws javax.ejb.CreateException,javax.ejb.FinderException,
					javax.naming.NamingException,java.rmi.RemoteException {
		final String methodName = "updateOrderPaymentMethod";
		ECTrace.entry( ECTraceIdentifiers.COMPONENT_ORDER, CLASSNAME, methodName );
		
		com.ibm.commerce.order.objimpl.OrderPaymentMethodInputData bOrderPaymentMethodInputData = new com.ibm.commerce.order.objimpl.OrderPaymentMethodInputData();
		bOrderPaymentMethodInputData.setOrderId(getOrder().getOrderIdInEJBType());
		bOrderPaymentMethodInputData.setPaymentMethodId(sPayMethod);
		bOrderPaymentMethodInputData.setPaymentDevice("0");
		bOrderPaymentMethodInputData.setRefundNumber(getRMA().getRmaIdInEJBType());

		bOrderPaymentMethodInputData.setPolicyId(getPolicyId());
		bOrderPaymentMethodInputData.setAccountId(getAccountId());
		bOrderPaymentMethodInputData.setTradingId(getRMA().getTradingIdInEJBType());
		bOrderPaymentMethodInputData.setRmaId(getRMA().getRmaIdInEJBType());
		bOrderPaymentMethodInputData.setActualAmount(getRefundAmount().negate());
		bOrderPaymentMethodInputData.setChargeAmount(getChargeAmount().negate());
		bOrderPaymentMethodInputData.setChargeAmountCurrency( getChargeAmountCurrency() );					//d30304
		bOrderPaymentMethodInputData.setChargeTime(new Timestamp(Calendar.getInstance().getTime().getTime()));
		
		OrderPaymentMethodAccessBean abOrdPayMthd = new OrderPaymentMethodAccessBean(bOrderPaymentMethodInputData, false);
			
		ECTrace.exit( ECTraceIdentifiers.COMPONENT_ORDER, CLASSNAME, methodName );
	}
}
